@@ -172,6 +172,10 @@ class ImageCrop:
         """
         需求文档： https://www.teambition.com/task/619e01f619f251003f289802
         """
+
+        if slot_config[DATA_SLOT_ID] == '3e1ba404-0710-4e2b-88b3-eae7ef2faa7b' and 'a1' in img.filename:
+            print(img.image_classification_list, img.filename)
+
         slot_width = slot_config.get('width')
         slot_height = slot_config.get('height')
         crop_info = slot_config.get(CROP)
@@ -260,20 +264,23 @@ class ImageCrop:
             transform_img_height = img.height * height_scale
 
             x_center = left + (right - left) / 2  # x 轴的居中
-            if transform_img_width >= slot_width and transform_img_height >= slot_height:  # 槽的上下左右都能被满足
+            if transform_img_width >= slot_width and transform_img_height >= slot_height \
+                    and y1*img.height*height_scale >= interest_top \
+                    and (1-y2)*img.height*height_scale >= slot_height-interest_top-interest_height:  # 槽的上下左右都能被满足
                 scale_x = scale_y = height_scale
-                y = y1
+                y = max(0, (y1 * img.height - interest_top / scale_x) / img.height)
                 x = self._alternative_interest_center(x_center, slot_width, transform_img_width, interest_left,
                                                       interest_width)
 
                 self.si.top_and_bottom_crop_result(True)  # 上下裁剪点都存在
 
-            elif transform_img_height >= slot_height and transform_img_width < slot_width:
+            elif transform_img_height >= slot_height and y1*img.height*height_scale >= interest_top \
+                    and (1-y2)*img.height*height_scale >= slot_height-interest_top-interest_height \
+                    and transform_img_width < slot_width:
                 width_scale = slot_width / img.width
-                y = y1
                 x = 0
                 scale_x = scale_y = width_scale
-
+                y = max(0, (y1 * img.height - interest_top / scale_x) / img.height)
                 self.si.top_and_bottom_crop_result(False)  # 上裁剪点存在
             else:
                 if retain_x_or_y == "x":
@@ -288,7 +295,7 @@ class ImageCrop:
 
                         max_ratio = max(min_top_ratio, min_bottom_ratio, min_img_left_ratio, min_img_right_ratio)
                         # 换算 回 原图的x
-                        x = ((interest_left + interest_width / 2) * max_ratio) / slot_width
+                        x = (0.5 * img.width - (interest_left + interest_width / 2) / max_ratio) / img.width
 
                     else:  # human 放在 兴趣区域内
                         min_human_left_ratio = self.__divide(interest_left + interest_width / 2, x_center * img.width)
@@ -298,10 +305,10 @@ class ImageCrop:
                         max_ratio = max(min_top_ratio, min_bottom_ratio, min_human_left_ratio, min_human_right_ratio)
 
                         # 换算 回 原图的x
-                        x = (x_center * img.width - (interest_left + interest_width / 2) / max_ratio) / slot_width
+                        x = (x_center * img.width - ((interest_left + interest_width / 2) / max_ratio)) / img.width
 
-                    y = y1
                     scale_x = scale_y = max_ratio
+                    y = max(0, (y1 * img.height - interest_top / scale_x) / img.height)
                     self.si.top_and_bottom_crop_result(False)  # 上裁剪点存在
 
                 elif retain_x_or_y == "interest_y":
@@ -327,7 +334,7 @@ class ImageCrop:
                         x = 0
                         scale_x = scale_y = width_scale
                         self.si.top_and_bottom_crop_result(False)  # 上裁剪点存在
-                    y = y1
+                    y = max(0, (y1 * img.height - interest_top / scale_x) / img.height)
 
                 else:
                     height_scale = slot_height / img.height
@@ -344,7 +351,7 @@ class ImageCrop:
                         width_scale = slot_width / img.width
                         x = 0
                         scale_x = scale_y = width_scale
-                    y = y1
+                    y = max(0, (y1 * img.height - interest_top / scale_x) / img.height)
 
                     self.si.top_and_bottom_crop_result(True)  # 上下裁剪点存在
 
